#
# spec file for package ocp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ocp
Version:        3.0.1
Release:        1.1
Summary:        Open Cubic Player for MOD/S3M/XM/IT/MIDI music files
# Code is GPL-2.0-or-later, Graphics and animations are CC-BY-3.0
License:        CC-BY-3.0 AND GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Players
URL:            https://stian.cubic.org/coding-ocp.php
#Git-Clone:     https://github.com/mywave82/opencubicplayer.git
Source0:        https://stian.cubic.org/ocp/%{name}-%{version}.tar.bz2
Source1:        ftp://ftp.cubic.org/pub/player/gfx/opencp25image1.zip
Source2:        ftp://ftp.cubic.org/pub/player/gfx/opencp25ani1.zip
Patch1:         ocp-ini-set-audio-output.patch
BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  gnu-unifont-otf-fonts
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  unzip
BuildRequires:  xa
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libancient)
BuildRequires:  pkgconfig(libcjson)
BuildRequires:  pkgconfig(libdiscid)
BuildRequires:  pkgconfig(libgme)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(mad)
BuildRequires:  pkgconfig(ncursesw)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xxf86vm)
BuildRequires:  pkgconfig(zlib)
Requires:       gnu-unifont-otf-fonts
Provides:       opencubicplayer
### Bundled libs
#./playtimidity/timidity-git
Provides:       bundled(timidity++)
#./playsid/libsidplayfp-git
Provides:       bundled(libsidplayfp)
#./playopl/adplug-git
Provides:       bundled(adplug)
#./playopl/adplugdb-git
Provides:       bundled(adplugdb)
#./playopl/libbinio-git
Provides:       bundled(libbinio)

%description
Open Cubic Player is a music file player ported from DOS that supports
Amiga MOD module formats and many variants, such as MTM, STM, 669,
S3M, XM, and IT.  It is also able to render MIDI files using sound
patches and play SID, OGG Vorbis, FLAC, and WAV files.  OCP provides a
nice text-based interface with several text-based and graphical
visualizations.

%prep
%setup -q
%autopatch -p1
unzip %{SOURCE1}
mv license.txt license-images.txt
unzip %{SOURCE2}
mv license.txt license-videos.txt

%build
%configure \
  --with-x11 \
  --with-alsa \
  --without-coreaudio \
  --without-oss \
  --with-lzw \
  --with-lzh \
  --with-flac \
  --without-sdl \
  --with-sdl2 \
  --with-mad \
  --with-unifont-otf=%{_datadir}/fonts/truetype/Unifont.otf \
  --with-unifont-csur-otf=%{_datadir}/fonts/truetype/Unifont_CSUR.otf \
  --with-unifont-upper-otf=%{_datadir}/fonts/truetype/Unifont_Upper.otf \
  --without-update-desktop-database \
  --without-update-mime-database
%make_build

%install
%make_install
# we package the docs ourselves
rm -Rv %{buildroot}%{_datadir}/doc/ocp/
# install images and animations
cp -pv CPPIC*.TGA CPANI*.DAT %{buildroot}%{_datadir}/%{name}/data

%check

%files
%license COPYING license-images.txt license-videos.txt
%doc AUTHORS BUGS CREDITS KEYBOARD_REMAPS SUID
%{_bindir}/ocp
%{_bindir}/ocp-curses
%{_bindir}/ocp-sdl2
%{_bindir}/ocp-vcsa
%{_bindir}/ocp-x11
%{_libdir}/ocp/
%{_datadir}/applications/cubic.org-opencubicplayer.desktop
%{_datadir}/icons/hicolor/*/apps/opencubicplayer.png
%{_datadir}/icons/hicolor/scalable/apps/opencubicplayer.svg
%{_datadir}/mime/packages/opencubicplayer.xml
%{_datadir}/ocp/
%{_mandir}/man1/ocp.1%{?ext_man}

%changelog
* Mon Dec 30 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0.1
  * [adplug] Update to latest master
    + This adds support for "Palladix" files.
    + HERAD files were not working as expected.
  * [sidplay] Update libsidplayfp to latest git version.
  * [modland.com] If waitpid() returns a fatal error, give up
    waiting.
  * [HVL] multiple updates:
  * files with size below 4096 were not able to be detected on
    modland.com virtual drive.
  * instrument-viewer must fetch the instruments from
    index 1, not 0.
  * track-viewer must fetch global commands from the actual
    number of channels in use.
  * reset the channel-information-cache on file-load, else we
    might try to dereference pointers from the previous song
    played.
  * [MDL] In loader, the calculation of two buffer-sizes were
    missing parentheses, causing incorrect calculation.
* Tue Dec 24 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0.0
  * Add more magic numbers for up and comming version of ancient
    (decompression library for solid files).
  * SetMode() did not have paremeters defined in the prototype,
    not all users had parameters defined. Caused crashes one some
    combination of mode changes.
  * Add modland.com support directly from the file browser using a
    local copy of the file-list provided by modland.com.
  * Speed up filebrowser if an earlier scanned .tar.gz now has
    unscanned modules. The archive is not persistent open due to
    caching.
  * XM files would smash the stack on big-endian due to to loops
    had counter-limits in reverse order in endian-reversal code.
  * SDL/SDL2 audio: Add missing mutex locking in two API functions.
  * SDL2 audio: Use SDL_LockAudioDevice, SDL_UnlockAudioDevice and
    SDL_CloseAudioDevice SDL 2.x functions instead of legacy 1.x
    functions.
  * Do not attempt to divide by zero, if a song is reported as
    zero long.
  * Logic for buffersize in playtimidity (MIDI files) was not
    working as expected, especially on Windows.
  * If a file was unable to be accessed, pressing ENTER on it
    would cause a NULL-pointer dereference (Problem
    introduced in v0.2.102, adding support for ancient)
  * Attempting to load a defective S3M file could trigger two
    different issues. Do not cal mcpSet(), since we have not
    initialized the mcp device yet, and the que variable was no
    reset on to NULL after free causing a double free in this
    special use case.
  * When adding a directory-tree to the playlist, group the files
    by their owning directory, and sort each group of files
    alphabetically (strcasecmp).
  * Detect Sidplayer files as playable.
  * modland.com stores "Atari Digi-Mix" as *.mix instead of *.ym,
    so add that file-extension.
  * Add FEST as a valid 4-channel signature.
  * Add "Atari STe/Falcon, Octalyser" CD61 and CD81 signatures.
  * Add "M&K!" as a valid MOD signature. These files are likely
    "His Master's Noise"
  * Add support for Atari Falcon, Digital Tracker (MOD) files.
  * Avoid double free(), could occure if trying to load an
    invalid MOD file
  * Adjust MIME database, multiple of the magic searches were too
    aggressive.
  * detecting .BAM files with .[0-9][0-9][0-9] filenames
  * Remove adplugdb->wipe() call, it is not for freeing memory
* Fri Apr  5 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.2.109
  Bugfix release
  * Remove a gcc warning when compiling boot/psetting.c
  * validate_xdg_dir_absolute() allocates a byte short when
    building the string buffer in one of the code-paths.
* Mon Apr  1 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.2.108
  Bugfix release
  * When detecting C++ version, ] and ) was out of order in
    configure.ac. This only became problematic in autoconf 2.72.
  * Playback via Game-Music-Emulator, the global loop module
    setting was not honored.
  * Mono FLAC files would crash, buffer retrieval expected
    (atleast) two channels to be present.
  * EOF detection got false positives in file-cache, FLAC files
    could fail to play
  * Labels should not appear in front of variables, clang can be
    strict on this.
* Mon Feb 19 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 0.2.107
  libsidplayfp:
  * Make it possible to tune parameters in real-time.
  * Update libsidplayfp to the latest master.
  * Plugin had an extra dirdbUnref() that should not be there.
  adplug:
  * Update adplug to latest master.
  * Scrolling the channel viewer could crash the player due to read
    of out-of-bound memory.
  * The wrapper OPL class OCP uses had some minor problems:
    + In OPL3 mode, if a channel was in 4-OP mode, the second half
    would always muted.
    + In OPL3 mode, if a channel was in 4-OP mode, you could mute
    the second half of the channel (in addition to the problem
    mentioned above).
    + When a channel is going in/out of 4-OP mode, mute was not
    consistent.
  * Refactor and use file-caching.
  * Add compression hint to the fie API, solid files should be
    scanned directly.
  * Differentiate unread (files not scanned) and files were the
    file content turned out to be unknown. Speeds up the file
    browser, especially if there are archives present.
  * ISO/TOC - Audio CDs could be unable to play after being
    looked up in the online discid-database.
  * Update libancient filter to match upto libancient master
    (needs matching support from host operating system for them to
    work).
  * Add support for *.RPG archive file from "Official Hamster
    Republic Role Playing Game Construction Engine", and *.BAM that
    in game data files as stored as *.1 *.2 *.3 etc.
  * Potential hang-bug in UDF (CDROM DVD image files) parser.
* Sat Aug  5 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 0.2.106
  * [IT] Increase the number of max-samples to match openMPT (it
    can export files with more samples that original tracker and
    Schism supports).
  * [devpdisk] Reported time during playback was random.
  * [adplug] Add support for SudoMakers RetroWave OPL3 Express,
    please configure it in setup:/adplugconfig.dev
  * [adplug] Make channel tracker aware of AM/FM modes so it more
    correctly can display visualization.
  * [adplug] Left/Right OPL3 logic was incorrect in the
    register-tracker.
  * [libancient] Add more fingerprints for compression formats
    that v2.1.0 can decompress.
  * [Linux CDROM] Fix deadlock.
  * [configure] cleanup --bindir --libdir and --datadir, and new
    syntax to override post ocp suffixes:
    ./configure LIBDIROCP=/usr/lib/ocp DATADIROCP=/usr/data/ocp
  * [configure] removed --with-dir-suffix
  * [CDROM *.CUE] REM didn't work as expected.
  * [CDROM *.CUE] files didn't work if containing INDEX 00.
  * [CDROM *.CUE] BINARY keyword should be little endian, but
    there are tools that produce big-endian files without marking
    them correctly. So we need to detect the endian used.
  * [CDROM *.CUE] files didn't include pregaps in the track table.
  * [CDROM *.TOC] files didn't split the logic for pregap and
    offset into the raw file.
  * [musicbrainz] Increase the buffersize, some data retrivals
    failed.
  * [global MIME database] Add adplug fileformats.
  * [global MIME database] Add Game Music Emulator fileformats.
  * [SDL2] if entering fullscreen while in graphical effect mode,
    it could not be exited without visiting a textmode resolution.
  * [SDL2] Use SDL_OpenAudioDevice(), else the expected audio
    format between SDL2 and OCP might not be what we expect
    causing random noise to be played.
  * [X11] non-Shm usage could fail to successfully create butter
    on window resize.
  * [X11] If background picture is loaded in GUI modes, it was not
    repainted on window-resize.
  * [unifont] Allow for unifont ttf/otf files to be placed in the
    datadir by using ./configure --with-unifont-relative (you still
    need to copy the files in).
  * [*.VGZ] Silently convert them to *.VGM
  * [GME] Add support for Game Music Emulator library (libgme) for
    playback of various retro console systems.
* Sat May 13 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 0.2.105
  * Avoid crash if attempting to access graphical viewer modes
    when running in curses (text only).
* Fri May 12 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 0.2.104
  * Update libsidplayfp
  * Update adplug
    + Latest version of the upstream version
  - Adds support for *.PIS and *.MTR
    + Reimplemented the OPL2/3 status viewer.
    + Buffer for compositing tracker data for music that supports
    this, was not cleared between pattern loads. Causing visual
    data to be accumulated.
    + OCP now supports multiple of the emulator implementations.
    + Default emulator to use has been changed.
    + Configuration dialog added into setup.
  * Elapsed time is now based on played samples and not counting
    seconds passed.
  * Screen resizing should be more consistent on remembering
    settings.
  * Files that are detected as valid for libancient but fails
    decompression, OCP failed to reset the filehandler
    read-position back to 0.
  * Track viewer had some excessive CPU usage
  * Analyzer viewer has the scale gain range increased, and the
    current gain is visible in the header.
  * Quick help documentation has been updated, with special focus
    on the keyboard shortcuts.
* Sat Feb 18 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 0.2.103
  * If an autoload plugin fails to load, do not hard fail if all
    the core plugins are statically linked in.
  * version 0.2.91 update missed setting the color for XM files
    in ocp.ini
  * Fix logic for setting screenmode vs ocp.ini. This is now the
    scheme and default values that SDL, SDL2 and X11 drivers use:
    [screen]
    screentype=5            ; 0=80x25, 1=80x30, 2=80x50, 3=80x60,
    4=132x25, 5=132x30, 6=132x50, 7=132x60, 8=custom
    fontsize=1              ; if screentype=8: 0=8x8, 1=8x16
    winwidth=1024           ; if screentype=8
    winheight=768           ; if screentype=8
  * insttype= setting in ocp.ini was no longer working and it was
    not maintained between songs.
  * Remove more external symbols from the devp*.so and devw*.so
    files, and API updates
  * setup:/devp/ and setup:/devw/ directories has been replaced
    with dialogs
  * Detect that C++17 is available, needed due to libancient
  * Failed detection of `update-mime-database` did not halt
    ./configure causing errors later during make instead
  * Update libsidplayfp to the latest version
- Drop patch:
  * 0001-When-compiling-code-against-libancient-ensure-that-C.patch
* Fri Feb 17 2023 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * ocp-ini-set-audio-output.patch
* Thu Feb 16 2023 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * 0001-When-compiling-code-against-libancient-ensure-that-C.patch
* Mon Feb 13 2023 Martin Hauke <mardnh@gmx.de>
- Complete specfile overhaul
- Update to version 0.2.102
  * https://github.com/mywave82/opencubicplayer/releases/tag/v0.2.102
* Wed Nov  6 2013 msrex@owncloud.com
- update to 0.1.21 and fixed SUSE packaging
  Sat Jan  9 00:00:00 UTC 2010 - stian (at) nixia.no
  - Initial makeover of the .spec file
